@@ -1,14 +1,15 @@
-from requests.structures import CaseInsensitiveDict
-from requests import Session, ConnectionError
+import logging
 import os
 import time
-import logging
 from datetime import datetime
 
+from requests import Session, ConnectionError
+from requests.structures import CaseInsensitiveDict
+
 BASE_URL = "https://api.planfact.io"
 MAX_SENDING_TRIES = 3
 MIN_TIME_BETWEEN_REQUEST = 0.1
-MAX_REQUSTS_PER_FUNCTION = 100
+MAX_REQUESTS_PER_FUNCTION = 100
 
 logger = logging.getLogger(__name__)
 
@@ -18,6 +19,7 @@ class PfInteraction:
         self.session = Session()
         self.headers = CaseInsensitiveDict()
         self.headers["Accept"] = "application/json"
+        self.headers["Content-Type"] = "application/json"
         self.time_at_last_request = time.time()
 
     def _get_header(self):
@@ -37,8 +39,8 @@ class PfInteraction:
                             'filter.changesFromDate': changes_from_date.strftime('%Y-%m-%dT%H:%M:%S')
                         })
             all_items = []
-            for i in range(MAX_REQUSTS_PER_FUNCTION):
-                res, status_code = self.request(method, path, data, params, headers)
+            for i in range(MAX_REQUESTS_PER_FUNCTION):
+                res, status_code = self.request(method=method, path=path, data=data, params=params, headers=headers)
                 all_items += res.json()['data']['items']
                 if len(res.json()['data']['items']) < params['paging.limit']:
                     break
@@ -57,25 +59,24 @@ class PfInteraction:
         else:
             raise RuntimeError('this is not an list operation')
 
-    def request(self, method, path, data=None, params=None, headers=None):
-        headers = self._get_header()
-
-        max_sending_tries = MAX_SENDING_TRIES
+    def request(self, method, path, data=None, json: str = None, params=None, headers=None):
+        if headers is None:
+            headers = self._get_header()
         # make sure that the rate is not to high
         time_passed = time.time() - self.time_at_last_request
         logger.debug('time passed %s' % str(time_passed))
-        # send the request,
-        for send_request_tries in range(max_sending_tries):
+        # send the request
+        for send_request_tries in range(MAX_SENDING_TRIES):
             # wait MIN_TIME_BETWEEN_REQUEST second
             if time_passed < MIN_TIME_BETWEEN_REQUEST:
                 logger.debug('have to wait %s' % str(MIN_TIME_BETWEEN_REQUEST - time_passed))
                 time.sleep(MIN_TIME_BETWEEN_REQUEST - time_passed)
             # reset time
             self.time_at_last_request = time.time()
-
             try:
                 response = self.session.request(method,
                                                 url=BASE_URL + path,
+                                                data=json,
                                                 json=data,
                                                 params=params,
                                                 headers=headers)
